@@ -64,7 +64,7 @@ SUPPORTED_ENDPOINT_SCHEME = ('http', 'https')
 
 def _trim_endpoint_api_version(url):
     """Trim API version and trailing slash from endpoint."""
-    return url.rstrip('/').rstrip(API_VERSION)
+    return url.rstrip('/').rstrip(API_VERSION).rstrip('/')
 
 
 def _extract_error_json(body):
@@ -274,7 +274,7 @@ class HTTPClient(VersionNegotiationMixin):
             body = strutils.mask_password(kwargs['body'])
             curl.append('-d \'%s\'' % body)
 
-        curl.append(urlparse.urljoin(self.endpoint_trimmed, url))
+        curl.append(self._make_connection_url(url))
         LOG.debug(' '.join(curl))
 
     @staticmethod
@@ -292,7 +292,10 @@ class HTTPClient(VersionNegotiationMixin):
         LOG.debug('\n'.join(dump))
 
     def _make_connection_url(self, url):
-        return urlparse.urljoin(self.endpoint_trimmed, url)
+        # NOTE(pas-ha) we already stripped trailing / from endpoint_trimmed
+        if not url.startswith('/'):
+            url = '/' + url
+        return self.endpoint_trimmed + url
 
     def _parse_version_headers(self, resp):
         return self._generic_parse_version_headers(resp.headers.get)
@@ -501,8 +504,16 @@ class SessionClient(VersionNegotiationMixin, adapter.LegacyJsonAdapter):
         return self._generic_parse_version_headers(resp.headers.get)
 
     def _make_simple_request(self, conn, method, url):
+        endpoint_filter = {
+            'interface': self.interface,
+            'service_type': self.service_type,
+            'region_name': self.region_name
+        }
+
         # NOTE: conn is self.session for this class
-        return conn.request(url, method, raise_exc=False)
+        return conn.request(url, method, raise_exc=False,
+                            user_agent=USER_AGENT,
+                            endpoint_filter=endpoint_filter)
 
     @with_retries
     def _http_request(self, url, method, **kwargs):
